@@ -2,11 +2,11 @@
   ----- File:        t1aaset.c 
   ----- Author:      Rainer Menzner (Rainer.Menzner@web.de)
                      Subsampling based on code by Raph Levien (raph@acm.org)
-  ----- Date:        2005-05-01
+  ----- Date:        2006-11-06
   ----- Description: This file is part of the t1-library. It contains
                      functions for antialiased setting of characters
 		     and strings of characters.
-  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-2005.
+  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-2006.
                      As of version 0.5, t1lib is distributed under the
 		     GNU General Public Library Lincense. The
 		     conditions can be found in the files LICENSE and
@@ -963,11 +963,21 @@ GLYPH *T1_AASetChar( int FontID, char charcode, float size,
   offset=0;
   target_ptr=aaglyph.bits;
   
-  /* We must check for n_vert==1 because the computation above is not
-     valid in this case */
-  if (n_vert==1)
-    v_start=v_start < v_end ? v_start : v_end;
+  /* We must check for n_vert==1 because then both v_start and v_end could / will
+     affect the same AA scan line. Because I'm forgetful, a reminder:
 
+          v_end |   000000000000000000000
+	        |   111111111111111111111  ^ 
+		Y   111111111111111111111  |
+                    000000000000000000000  | v_start
+
+     In order to count the v_end from bottom to top, we express it as (T1aa_level-v_end).
+     The number of rows to take into account is then v_start-(T1aa_level-v_end).
+  */
+  if (n_vert==1) {
+    v_start=v_start - (T1aa_level - v_end);
+  }
+  
   ptr = glyph->bits;
   for (i = 0; i < n_vert; i++) {
     if (i==0)
@@ -1185,10 +1195,12 @@ GLYPH *T1_AASetString( int FontID, char *string, int len,
   offset=0;
   target_ptr=aastring_glyph.bits;
   
-  /* We must check for n_vert==1 because the computation above is not
-     valid in this case */
-  if (n_vert==1)
-    v_start=v_start < v_end ? v_start : v_end;
+  /* We must check for n_vert==1 because then both v_start and v_end could / will
+     affect the same AA scan line. 
+  */
+  if (n_vert==1) {
+    v_start=v_start - (T1aa_level - v_end);
+  }
   
   ptr = glyph->bits;
   for (i = 0; i < n_vert; i++) {
@@ -1396,10 +1408,12 @@ GLYPH* T1_AASetRect( int FontID, float size,
   offset=0;
   target_ptr=aaglyph.bits;
   
-  /* We must check for n_vert==1 because the computation above is not
-     valid in this case */
-  if (n_vert==1)
-    v_start=v_start < v_end ? v_start : v_end;
+  /* We must check for n_vert==1 because then both v_start and v_end could / will
+     affect the same AA scan line. 
+  */
+  if (n_vert==1) {
+    v_start=v_start - (T1aa_level - v_end);
+  }
 
   ptr = glyph->bits;
   for (i = 0; i < n_vert; i++) {
@@ -1819,10 +1833,12 @@ GLYPH *T1_AAFillOutline( T1_OUTLINE *path, int modflag)
   offset=0;
   target_ptr=aaglyph.bits;
   
-  /* We must check for n_vert==1 because the computation above is not
-     valid in this case */
-  if (n_vert==1)
-    v_start=v_start < v_end ? v_start : v_end;
+  /* We must check for n_vert==1 because then both v_start and v_end could / will
+     affect the same AA scan line.
+  */
+  if (n_vert==1) {
+    v_start=v_start - (T1aa_level - v_end);
+  }
 
   ptr = glyph->bits;
   for (i = 0; i < n_vert; i++) {
